==> moodle_1.3.1.orig.tar.gz: moodle/lang/zh_tw_utf8/resource.php <==
<?PHP // $Id: resource.php,v 1.1 2004/04/27 14:03:15 moodler Exp $ 
      // resource.php - created with Moodle 1.2 Beta (2004022400)


$string['addresource'] = '新增資源';
$string['chooseafile'] = '選擇或上傳一個檔';
$string['configdefaulturl'] = '這個值被使用來提示URL，當建立一個新的URL資源連結時';
$string['configfilterexternalpages'] = '啟用這個設定，將導致所有外部資源被現有的網站過濾設定所處理。啟用這個選項可能導致系統效能降低。請小心使用，並確定你真的有這個需求。';
$string['configframesize'] = '當網頁或上載的檔案在框架中顯示，這個設定值決定了框架大小。';
$string['configpopup'] = '當新增一個新資源時，這個資源是否要採用彈出式視窗，以提供閱讀。這個選項預設是啟用的。';
$string['configpopupdirectories'] = '彈出視窗是否顯示預設目錄鏈結？';
$string['configpopupheight'] = '新視窗預設高度？';
$string['configpopuplocation'] = '彈出視窗是否顯示位址欄？';
$string['configpopupmenubar'] = '彈出視窗是否顯示功能表欄？';
$string['configpopupresizable'] = '彈出視窗是否可以調整大小？';
$string['configpopupscrollbars'] = '彈出視窗是否可滾動？';
$string['configpopupstatus'] = '彈出視窗是否顯示狀態欄？';
$string['configpopuptoolbar'] = '彈出視窗是否顯示工具欄？';
$string['configpopupwidth'] = '新視窗預設寬度？';
$string['configwebsearch'] = '當加入一個超連結時，這個連結位址提供一個網站來幫助使用者搜尋你要的相關網址';
$string['directlink'] = '直接連結這個檔案';
$string['editingaresource'] = '編輯資源';
$string['example'] = '範例';
$string['examplereference'] = 'Tobin, K. & Tippins, D (1993) Constructivism as a Referent for Teaching and Learning. In: K. Tobin (Ed) The Practice of Constructivism in Science Education, pp 3-21, Lawrence-Erlbaum, Hillsdale, NJ.';
$string['exampleurl'] = '網址 http://fire.tkvs.ylc.edu.tw/moodle';
$string['fetchclienterror'] = '網頁存取錯誤，你可能提供了錯誤的網址';
$string['fetcherror'] = '存取網頁發生錯誤';
$string['fetchservererror'] = '當存取遠端網頁時，有錯誤發生。可能是程式執行錯誤';
$string['filename'] = '檔案名稱';
$string['fulltext'] = '文字內容';
$string['htmlfragment'] = '網頁片段';
$string['modulename'] = '線上資源';
$string['modulenameplural'] = '線上資源';
$string['neverseen'] = '無人閱覽';
$string['newdirectories'] = '顯示目錄鏈結';
$string['newfullscreen'] = '全螢幕';
$string['newheight'] = '預設視窗高度(像素)';
$string['newlocation'] = '顯示位址欄';
$string['newmenubar'] = '顯示功能表列';
$string['newresizable'] = '允許調整視窗大小';
$string['newscrollbars'] = '允許視窗捲動';
$string['newstatus'] = '顯示狀態列';
$string['newtoolbar'] = '顯示工具列';
$string['newwidth'] = '預設視窗寬度(像素)';
$string['newwindow'] = '開新視窗';
$string['newwindowopen'] = '在新視窗打開';
$string['note'] = '提示';
$string['notefile'] = '請利用 <A HREF=$a >檔案管理</A>上載檔案. 上載的檔案都會顯示在選單中';
$string['notypechosen'] = '請先選擇資源型態. 請回前頁重試一次.';
$string['popupresource'] = '這個資源應顯示在彈出視窗';
$string['popupresourcelink'] = '如果未生效，請點選這裡： $a';
$string['resourcetype'] = '資源型態';
$string['resourcetype1'] = '參考文獻';
$string['resourcetype2'] = '網頁';
$string['resourcetype3'] = '已上載的檔案';
$string['resourcetype4'] = '純文字內容';
$string['resourcetype5'] = '外部網頁連結';
$string['resourcetype6'] = '網頁文件';
$string['resourcetype7'] = '執行程式';
$string['resourcetype8'] = 'Wiki 文件';

?>

==> moodle_1.5.3+20060108.orig.tar.gz: moodle/lang/zh_tw_utf8/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.2 Beta (2004022400)


$string['addresource'] = '新增資源';
$string['chooseafile'] = '選擇或上傳一個檔';
$string['configdefaulturl'] = '這個值被使用來提示URL，當建立一個新的URL資源連結時';
$string['configfilterexternalpages'] = '啟用這個設定，將導致所有外部資源被現有的網站過濾設定所處理。啟用這個選項可能導致系統效能降低。請小心使用，並確定你真的有這個需求。';
$string['configframesize'] = '當網頁或上載的檔案在框架中顯示，這個設定值決定了框架大小。';
$string['configpopup'] = '當新增一個新資源時，這個資源是否要採用彈出式視窗，以提供閱讀。這個選項預設是啟用的。';
$string['configpopupdirectories'] = '彈出視窗是否顯示預設目錄鏈結？';
$string['configpopupheight'] = '新視窗預設高度？';
$string['configpopuplocation'] = '彈出視窗是否顯示位址欄？';
$string['configpopupmenubar'] = '彈出視窗是否顯示功能表欄？';
$string['configpopupresizable'] = '彈出視窗是否可以調整大小？';
$string['configpopupscrollbars'] = '彈出視窗是否可滾動？';
$string['configpopupstatus'] = '彈出視窗是否顯示狀態欄？';
$string['configpopuptoolbar'] = '彈出視窗是否顯示工具欄？';
$string['configpopupwidth'] = '新視窗預設寬度？';
$string['configwebsearch'] = '當加入一個超連結時，這個連結位址提供一個網站來幫助使用者搜尋你要的相關網址';
$string['directlink'] = '直接連結這個檔案';
$string['editingaresource'] = '編輯資源';
$string['example'] = '範例';
$string['examplereference'] = 'Tobin, K. & Tippins, D (1993) Constructivism as a Referent for Teaching and Learning. In: K. Tobin (Ed) The Practice of Constructivism in Science Education, pp 3-21, Lawrence-Erlbaum, Hillsdale, NJ.';
$string['exampleurl'] = '網址 http://fire.tkvs.ylc.edu.tw/moodle';
$string['fetchclienterror'] = '網頁存取錯誤，你可能提供了錯誤的網址';
$string['fetcherror'] = '存取網頁發生錯誤';
$string['fetchservererror'] = '當存取遠端網頁時，有錯誤發生。可能是程式執行錯誤';
$string['filename'] = '檔案名稱';
$string['fulltext'] = '文字內容';
$string['htmlfragment'] = '網頁片段';
$string['modulename'] = '線上資源';
$string['modulenameplural'] = '線上資源';
$string['neverseen'] = '無人閱覽';
$string['newdirectories'] = '顯示目錄鏈結';
$string['newfullscreen'] = '全螢幕';
$string['newheight'] = '預設視窗高度(像素)';
$string['newlocation'] = '顯示位址欄';
$string['newmenubar'] = '顯示功能表列';
$string['newresizable'] = '允許調整視窗大小';
$string['newscrollbars'] = '允許視窗捲動';
$string['newstatus'] = '顯示狀態列';
$string['newtoolbar'] = '顯示工具列';
$string['newwidth'] = '預設視窗寬度(像素)';
$string['newwindow'] = '開新視窗';
$string['newwindowopen'] = '在新視窗打開';
$string['note'] = '提示';
$string['notefile'] = '請利用 <a href=\"$a\" >檔案管理</a>上載檔案. 上載的檔案都會顯示在選單中';
$string['notypechosen'] = '請先選擇資源型態. 請回前頁重試一次.';
$string['popupresource'] = '這個資源應顯示在彈出視窗';
$string['popupresourcelink'] = '如果未生效，請點選這裡： $a';
$string['resourcetype'] = '資源型態';
$string['resourcetype1'] = '參考文獻';
$string['resourcetype2'] = '網頁';
$string['resourcetype3'] = '已上載的檔案';
$string['resourcetype4'] = '純文字內容';
$string['resourcetype5'] = '外部網頁連結';
$string['resourcetype6'] = '網頁文件';
$string['resourcetype7'] = '執行程式';
$string['resourcetype8'] = 'Wiki 文件';

?>
